@@ -69,6 +69,11 @@ error = head (sort x) ==> minimum x
 error = last (sort x) ==> maximum x
 error = head (sortBy f x) ==> minimumBy f x
 error = last (sortBy f x) ==> maximumBy f x
+error "Avoid reverse" = reverse (sort x) ==> sortBy (flip compare) x
+error "Avoid reverse" = reverse (sortBy f x) ==> sortBy (flip f) x
+warn  = flip (g `on` h) ==> flip g `on` h
+warn  = (f `on` g) `on` h ==> f `on` (g . h)
+
 
 -- READ/SHOW
 
@@ -85,15 +90,23 @@ warn = concat [a, b] ==> a ++ b
 warn "Use map once" = map f (map g x) ==> map (f . g) x
 warn  = x !! 0 ==> head x
 error = take n (repeat x) ==> replicate n x
+error = map f (replicate n x) ==> replicate n (f x)
+error = map f (repeat x) ==> repeat (f x)
 error = head (reverse x) ==> last x
 error = head (drop n x) ==> x !! n where _ = isNat n
 error = reverse (tail (reverse x)) ==> init x where note = IncreasesLaziness
+error "Avoid reverse" = reverse (reverse x) ==> x where note = IncreasesLaziness
 -- error = take (length x - 1) x ==> init x -- not true for x == []
 error = isPrefixOf (reverse x) (reverse y) ==> isSuffixOf x y
 error = foldr (++) [] ==> concat
 error = foldl (++) [] ==> concat where note = IncreasesLaziness
 error = span (not . p) ==> break p
 error = break (not . p) ==> span p
+error = (takeWhile p x, dropWhile p x) ==> span p x
+error = fst (span p x) ==> takeWhile p x
+error = snd (span p x) ==> dropWhile p x
+error = fst (break p x) ==> takeWhile (not . p) x
+error = snd (break p x) ==> dropWhile (not . p) x
 error = concatMap (++ "\n") ==> unlines
 error = map id ==> id
 error = or (map p x) ==> any p x
@@ -137,7 +150,6 @@ warn "Use null" = length x > 0 ==> not (null x) where note = IncreasesLaziness
 warn "Use null" = length x >= 1 ==> not (null x) where note = IncreasesLaziness
 error "Take on a non-positive" = take i x ==> [] where _ = isNegZero i
 error "Drop on a non-positive" = drop i x ==> x where _ = isNegZero i
-error = (takeWhile p l, dropWhile p l) ==> span p l
 
 
 -- FOLDS
@@ -169,13 +181,13 @@ error = foldr mplus mzero ==> msum
 
 error = (\x -> x) ==> id
 error = (\x y -> x) ==> const
-error = (\(x,y) -> y) ==> snd where _ = notIn x y
-error = (\(x,y) -> x) ==> fst where _ = notIn y x
-warn "Use curry" = (\x y -> f (x,y)) ==> curry f where _ = notIn [x,y] f
-warn "Use uncurry" = (\(x,y) -> f x y) ==> uncurry f where _ = notIn [x,y] f; note = IncreasesLaziness
+error = (\(x,y) -> y) ==> snd
+error = (\(x,y) -> x) ==> fst
+warn "Use curry" = (\x y -> f (x,y)) ==> curry f
+warn "Use uncurry" = (\(x,y) -> f x y) ==> uncurry f where note = IncreasesLaziness
 error "Redundant $" = (($) . f) ==> f
 error "Redundant $" = (f $) ==> f
-warn  = (\x -> y) ==> const y where _ = isAtom y && notIn x y
+warn  = (\x -> y) ==> const y where _ = isAtom y
 error "Redundant flip" = flip f x y ==> f y x where _ = isApp original
 warn  = (\a b -> g (f a) (f b)) ==> g `Data.Function.on` f
 
@@ -226,10 +238,10 @@ error "Too strict if" = (if c then f x else f y) ==> f (if c then x else y) wher
 error = id *** g ==> second g
 error = f *** id ==> first f
 error = zip (map f x) (map g x) ==> map (f Control.Arrow.&&& g) x
-warn  = (\(x,y) -> (f x, g y)) ==> f Control.Arrow.*** g where _ = notIn [x,y] [f,g]
-warn  = (\x -> (f x, g x)) ==> f Control.Arrow.&&& g where _ = notIn x [f,g]
-warn  = (\(x,y) -> (f x,y)) ==> Control.Arrow.first f where _ = notIn [x,y] f
-warn  = (\(x,y) -> (x,f y)) ==> Control.Arrow.second f where _ = notIn [x,y] f
+warn  = (\(x,y) -> (f x, g y)) ==> f Control.Arrow.*** g
+warn  = (\x -> (f x, g x)) ==> f Control.Arrow.&&& g
+warn  = (\(x,y) -> (f x,y)) ==> Control.Arrow.first f
+warn  = (\(x,y) -> (x,f y)) ==> Control.Arrow.second f
 warn  = (f (fst x), g (snd x)) ==> (f Control.Arrow.*** g) x
 warn "Redundant pair" = (fst x, snd x) ==>  x where note = DecreasesLaziness
 
@@ -261,8 +273,8 @@ warn = a >> return () ==> void a
 warn = fmap (const ()) ==> void
 error = flip (>=>) ==> (<=<)
 error = flip (<=<) ==> (>=>)
-error = (\x -> f x >>= g) ==> f Control.Monad.>=> g where _ = notIn x [f,g]
-error = (\x -> f =<< g x) ==> f Control.Monad.<=< g where _ = notIn x [f,g]
+error = (\x -> f x >>= g) ==> f Control.Monad.>=> g
+error = (\x -> f =<< g x) ==> f Control.Monad.<=< g
 error = a >> forever a ==> forever a
 warn = liftM2 id ==> ap
 error = mapM (uncurry f) (zip l m) ==> zipWithM f l m
@@ -279,6 +291,8 @@ error = sequence (zipWith f x y) ==> Control.Monad.zipWithM f x y
 error = sequence_ (zipWith f x y) ==> Control.Monad.zipWithM_ f x y
 error = sequence (replicate n x) ==> Control.Monad.replicateM n x
 error = sequence_ (replicate n x) ==> Control.Monad.replicateM_ n x
+error = mapM f (replicate n x) ==> Control.Monad.replicateM n (f x)
+error = mapM_ f (replicate n x) ==> Control.Monad.replicateM_ n (f x)
 error = mapM f (map g x) ==> mapM (f . g) x
 error = mapM_ f (map g x) ==> mapM_ (f . g) x
 error = mapM id ==> sequence
@@ -362,7 +376,6 @@ error "Redundant fromInteger" = fromInteger x ==> x where _ = isLitInt x
 warn  = x + negate y ==> x - y
 warn  = 0 - x ==> negate x
 warn  = log y / log x ==> logBase x y
-warn  = x ** 0.5 ==> sqrt x
 warn  = sin x / cos x ==> tan x
 warn  = sinh x / cosh x ==> tanh x
 warn  = n `rem` 2 == 0 ==> even n
@@ -370,7 +383,6 @@ warn  = n `rem` 2 /= 0 ==> odd n
 warn  = not (even x) ==> odd x
 warn  = not (odd x) ==> even x
 warn  = x ** 0.5 ==> sqrt x
-warn  = x ^^ y ==> x ** y where _ = isLitInt y
 warn  "Use 1" = x ^ 0 ==> 1
 warn  = round (x - 0.5) ==> floor x
 
@@ -445,14 +457,17 @@ error "Evaluate" = const x y ==> x
 
 -- COMPLEX
 
+{-
+-- these would be a good idea, but we have not yet proven them and they seem to have side conditions
 error "Use isPrefixOf" = take (length t) s == t ==> t `Data.List.isPrefixOf` s
 error "Use isPrefixOf" = (take i s == t) ==> _eval_ ((i >= length t) && (t `Data.List.isPrefixOf` s))
     where _ = (isList t || isLit t) && isPos i
+-}
 
 {-
 -- clever hint, but not actually a good idea
 warn  = (do a <- f; g a) ==> f >>= g
-    where _ = (isAtom f || isApp f) && notIn a g
+    where _ = (isAtom f || isApp f)
 -}
 
 test = hints named test are to allow people to put test code within hint files
@@ -477,7 +492,6 @@ no  = if a then 1 else if b then 3 else 2
 yes = a >>= return . id -- Control.Monad.liftM id a
 yes = (x !! 0) + (x !! 2) -- head x
 yes = if b < 42 then [a] else [] -- [a | b < 42]
-yes = take 5 (foo xs) == "hello" -- "hello" `Data.List.isPrefixOf` foo xs
 no  = take n (foo xs) == "hello"
 yes = head (reverse xs) -- last xs
 yes = reverse xs `isPrefixOf` reverse ys -- isSuffixOf xs ys
@@ -525,7 +539,6 @@ yes = [v | v <- xs] -- xs
 no  = [Left x | Left x <- xs]
 yes = Map.union a b -- a `Map.union` b
 when p s = if p then s else return ()
-yes = x ^^ 18 -- x ** 18
 no = x ^^ 18.5
 instance Arrow (->) where first f = f *** id
 yes = fromInteger 12 -- 12
@@ -550,6 +563,7 @@ main = take (-5) x -- []
 main = take (-y) x
 main = take 4 x
 main = let (first, rest) = (takeWhile p l, dropWhile p l) in rest -- span p l
+main = map $ \ d -> ([| $d |], [| $d |])
 
 import Prelude \
 yes = flip mapM -- Control.Monad.forM
