@@ -1,6 +1,9 @@
 
 module HLint.Generalise where
 
+import Data.Monoid
+import Control.Monad
+
 warn = concatMap ==> (=<<)
 warn = liftM ==> fmap
 warn = map ==> fmap
