@@ -5,6 +5,7 @@ module HLint(hlint, Suggestion, suggestionLocation, suggestionSeverity, Severity
 import Control.Monad
 import Data.List
 import Data.Maybe
+import System.Exit
 
 import CmdLine
 import Settings
@@ -48,8 +49,10 @@ hlint :: [String] -> IO [Suggestion]
 hlint args = do
     cmd@Cmd{..} <- getCmd args
     let flags = parseFlags{cppFlags=cmdCpp, encoding=cmdEncoding, language=cmdLanguage}
-    if cmdTest then
-        test (\x -> hlint x >> return ()) cmdDataDir cmdGivenHints >> return []
+    if cmdTest then do
+        failed <- test (\x -> hlint x >> return ()) cmdDataDir cmdGivenHints
+        when (failed > 0) exitFailure
+        return []
      else if notNull cmdProof then do
         s <- readAllSettings cmd flags
         let reps = if cmdReports == ["report.html"] then ["report.txt"] else cmdReports
