@@ -19,6 +19,8 @@ evaluate1 (App s len (Lit _ (String _ xs _))) | len ~= "length" = Lit s $ Int s
 evaluate1 (App s len (List _ xs)) | len ~= "length" = Lit s $ Int s n (show n)
     where n = fromIntegral $ length xs
 evaluate1 (view -> App2 op (Lit _ x) (Lit _ y)) | op ~= "==" = toNamed $ show $ x =~= y
+evaluate1 (view -> App2 op (Lit _ (Int _ x _)) (Lit _ (Int _ y _)))
+    | op ~= ">=" = toNamed $ show $ x >= y
 evaluate1 (view -> App2 op x y)
     | op ~= "&&" && x ~= "True"  = y
     | op ~= "&&" && x ~= "False" = x
