@@ -67,6 +67,9 @@ fromTyParen :: Type s -> Type s
 fromTyParen (TyParen _ x) = fromTyParen x
 fromTyParen x = x
 
+fromDeriving :: Deriving s -> [InstHead s]
+fromDeriving (Deriving _ x) = x
+
 -- is* :: Exp_ -> Bool
 -- is* :: Decl_ -> Bool
 isVar Var{} = True; isVar _ = False
@@ -93,17 +96,12 @@ isParComp ParComp{} = True; isParComp _ = False
 isPatTypeSig PatTypeSig{} = True; isPatTypeSig _ = False
 isQuasiQuote QuasiQuote{} = True; isQuasiQuote _ = False
 isSpliceDecl SpliceDecl{} = True; isSpliceDecl _ = False
+isNewType NewType{} = True; isNewType _ = False
 
 isSection LeftSection{} = True
 isSection RightSection{} = True
 isSection _ = False
 
--- which names are bound by a declaration
-declBind :: Decl_ -> [String]
-declBind (FunBind _ (Match _ x _ _ _ : _)) = [prettyPrint x]
-declBind (PatBind _ x _ _ _) = pvars x
-declBind _ = []
-
 
 allowRightSection x = x `notElem` ["-","#"]
 allowLeftSection x = x /= "#"
@@ -251,13 +249,6 @@ childrenS :: Biplate x (f S) => x -> [f S]
 childrenS = childrenBi
 
 
-vars :: Biplate a Exp_ => a -> [String]
-vars xs = [prettyPrint x | Var _ (UnQual _ x) <- universeS xs]
-
-pvars :: Biplate a Pat_ => a -> [String]
-pvars xs = [prettyPrint x | PVar _ x <- universeS xs]
-
-
 -- return the parent along with the child
 universeParentExp :: Biplate a Exp_ => a -> [(Maybe (Int, Exp_), Exp_)]
 universeParentExp xs = concat [(Nothing, x) : f x | x <- childrenBi xs]
