@@ -48,6 +48,9 @@ niceLambda [x] y | Just z <- factor y, x `notElem` vars z = z
         factor (Paren _ y@App{}) = factor y
         factor _ = Nothing
 
+-- \x -> (x +) ==> (+)
+niceLambda [x] (LeftSection _ (view -> Var_ x1) op) | x == x1 = opExp op
+
 -- base case
 niceLambda ps x = Lambda an (map toNamed ps) x
 
@@ -65,7 +68,7 @@ niceDotApp a b | a ~= "$" = b
 simplifyExp :: Exp_ -> Exp_
 simplifyExp (InfixApp _ x dol y) | isDol dol = App an x (paren y)
 simplifyExp (Let _ (BDecls _ [PatBind _ (view -> PVar_ x) Nothing (UnGuardedRhs _ y) Nothing]) z)
-    | x `notElem` vars y && x `notElem` pvars z && length (filter (== x) (vars z)) <= 1 = transform f z
+    | x `notElem` vars y && length [() | UnQual _ a <- universeS z, prettyPrint a == x] <= 1 = transform f z
     where f (view -> Var_ x') | x == x' = paren y
           f x = x
 simplifyExp x = x
