@@ -1,7 +1,16 @@
+{-
+The parallel function (specialised to lists) is equivalent to:
+
+import Control.Parallel.Strategies
+parallel :: [IO [a]] -> IO [[a]]
+parallel = return . withStrategy (parList $ seqList r0) . map unsafePerformIO
+
+However, this version performs about 10% slower with 2 processors in GHC 6.12.1
+-}
 
 module Parallel(parallel) where
 
-import System.IO.Unsafe(unsafeInterleaveIO)
+import System.IO.Unsafe
 import GHC.Conc(numCapabilities)
 import Control.Concurrent
 import Control.Monad
@@ -23,7 +32,7 @@ parallelN :: [IO a] -> IO [a]
 parallelN xs = do
     ms <- mapM (const newEmptyMVar) xs
     chan <- newChan
-    mapM (writeChan chan . Just) $ zip ms xs
+    mapM_ (writeChan chan . Just) $ zip ms xs
     replicateM_ numCapabilities (writeChan chan Nothing >> forkIO (f chan))
     parallel1 $ map takeMVar ms
     where
