@@ -121,7 +121,7 @@ typeCheckHints hints = bracket
             ,"_eval_ = id"] ++
             ["{-# LINE " ++ show (startLine $ ann rhs) ++ " " ++ show (fileName $ ann rhs) ++ " #-}\n" ++
              prettyPrint (PatBind an (toNamed $ "test" ++ show i) Nothing bod Nothing)
-            | (i, MatchExp _ _ _ lhs rhs side _) <- zip [1..] matches, "notTypeSafe" `notElem` vars side
+            | (i, MatchExp _ _ _ lhs rhs side _) <- zip [1..] matches, "notTypeSafe" `notElem` vars (maybeToList side)
             , let vs = map toNamed $ nub $ filter isUnifyVar $ vars lhs ++ vars rhs
             , let inner = InfixApp an (Paren an lhs) (toNamed "==>") (Paren an rhs)
             , let bod = UnGuardedRhs an $ if null vs then inner else Lambda an vs inner]
@@ -216,19 +216,36 @@ checkInputOutput main xs = do
         handle (\(e::SomeException) -> print e) $
         handle (\(e::ExitCode) -> return ()) $
         main flags
+    let gotValid = isJust got
     want <- fmap lines $ reader "output"
+    (want,got) <- return $ matchStarStar want $ fromMaybe [] got
 
-    let eq w g = w == g || ("*" `isSuffixOf` w && init w `isPrefixOf` g)
-    case got of
-        Nothing -> putStrLn "Warning: failed to capture output (GHC too old?)" >> return pass
-        Just got | length got == length want && and (zipWith eq want got) -> return pass
-                 | otherwise -> do
-            let trail = replicate (max (length got) (length want)) "<EOF>"
-            let (i,g,w):_ = [(i,g,w) | (i,g,w) <- zip3 [1..] (got++trail) (want++trail), not $ eq w g]
-            putStrLn $ unlines
-                ["TEST FAILURE IN tests/" ++ pre
-                ,"DIFFER ON LINE: " ++ show i
-                ,"GOT : " ++ g
-                ,"WANT: " ++ w]
-            when (null want) $ putStrLn $ unlines $ "FULL OUTPUT FOR GOT:" : got
-            return failure
+    if not gotValid then
+        putStrLn "Warning: failed to capture output (GHC too old?)" >> return pass
+     else if length got == length want && and (zipWith matchStar want got) then
+        return pass
+     else do
+        let trail = replicate (max (length got) (length want)) "<EOF>"
+        let (i,g,w):_ = [(i,g,w) | (i,g,w) <- zip3 [1..] (got++trail) (want++trail), not $ matchStar w g]
+        putStrLn $ unlines
+            ["TEST FAILURE IN tests/" ++ pre
+            ,"DIFFER ON LINE: " ++ show i
+            ,"GOT : " ++ g
+            ,"WANT: " ++ w]
+        when (null want) $ putStrLn $ unlines $ "FULL OUTPUT FOR GOT:" : got
+        return failure
+
+
+-- | First string may have stars in it (the want)
+matchStar :: String -> String -> Bool
+matchStar ('*':xs) ys = any (matchStar xs) $ tails ys
+matchStar (x:xs) (y:ys) = x == y && matchStar xs ys
+matchStar [] [] = True
+matchStar _ _ = False
+
+
+matchStarStar :: [String] -> [String] -> ([String], [String])
+matchStarStar want got = case break (== "**") want of
+    (_, []) -> (want, got)
+    (w1,_:w2) -> (w1++w2, g1 ++ revTake (length w2) g2)
+        where (g1,g2) = splitAt (length w1) got
