@@ -70,8 +70,8 @@ headDef :: a -> [a] -> a
 headDef x [] = x
 headDef x (y:ys) = y
 
-isLeft Left{} = True; isLeft _ = False
-isRight = not . isLeft
+isLeft_ Left{} = True; isLeft_ _ = False
+isRight_ = not . isLeft_
 
 unzipEither :: [Either a b] -> ([a], [b])
 unzipEither (x:xs) = case x of
@@ -110,6 +110,12 @@ unsnoc :: [a] -> ([a],a)
 unsnoc [] = error "Unsnoc on empty list"
 unsnoc xs = (init xs, last xs)
 
+revTake :: Int -> [a] -> [a]
+revTake i = reverse . take i . reverse
+
+concatUnzip :: [([a], [b])] -> ([a], [b])
+concatUnzip = (concat *** concat) . unzip
+
 
 ---------------------------------------------------------------------
 -- DATA.TUPLE
@@ -246,7 +252,7 @@ universeParentBi = concatMap universeParent . childrenBi
 -- LANGUAGE.HASKELL.EXTS.EXTENSION
 
 defaultExtensions :: [Extension]
-defaultExtensions = knownExtensions \\ badExtensions
+defaultExtensions = [e | e@EnableExtension{} <- knownExtensions] \\ map EnableExtension badExtensions
 
 badExtensions =
     [Arrows -- steals proc
